California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 001E - MENTAL HEALTH SERVICES FUNDING. TEMPORARY REALLOCATION. HELPS BALANCE STATE BUDGET. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1316221 | NO ON PROP 1D AND 1E - DON'T CUT CHILDREN'S SERVICES AND MENTAL HEALTH CARE - SPONSORED BY MENTAL HEALTH ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1317867 | AMERICAN FEDERATION OF STATE, COUNTY & LOCAL MUNICIPAL EMPLOYEES LOCAL 2620 ISSUES COMMITEE, YES ON 1A, 1B, 1C, 1D, 1E AND 1F | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1317887 | STOP TAXING US: NO ON 1A-F | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1315905 | BUDGET REFORM NOW, A COALITION OF TAXPAYERS, BUSINESS, LABOR, EDUCATORS, PUBLIC SAFETY, SENIORS, GOVERNOR SCHWARZENEGGER'S CALIFORNIA DREAM TEAM, A BALLOT MEASURE COMM"..." | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1261406 | SCHWARZENEGGER'S CALIFORNIA DREAM TEAM, A BALLOT MEASURE COMMITTEE, GOVERNOR | SUPPORT